@@ -4,7 +4,7 @@ from .parse import *
 from .check import *
 from .visualization import *
 
-__all__ = ['generate_annofile', 'generate_annotxt',
+__all__ = ['generate_annofile', 'generate_annotxt', 'generate_train_test_dataset', 'generate_annodataset',
            'parse_label', 'parse_txt',
            'modify_annoroot', 'modify_annocls', 'modify_label',
            'print_label', 'check_bboxlabel',
